# EC3 Python Wrapper

UNDER ACTIVE DEVELOPMENT. MORE DOCUMENTATION AND FUNCTIONALITY COMING SOON.

This is a Python wrapper for working with the Building Transparency EC3 API.
Documentation for the EC3 API can be found at [https://buildingtransparency.org/ec3/manage-apps/api-doc/api](https://buildingtransparency.org/ec3/manage-apps/api-doc/api)

## Installing

```
pip install ec3-python-wrapper
```

## Documentation

For documentation on how to use the EC3 Python Wrapper visit:
[https://ec3-python-wrapper.readthedocs.io/](https://ec3-python-wrapper.readthedocs.io/)

### Usage Example

A Jupyter Notebook with some examples onf how to use the EC3 Python Wrapper can be found [here](ec3_jupyter.ipynb)

## Credits

* Obviously none of this would exist without the great efforts of the [Building Transparency](https://buildingtransparency.org/ec3) team and the EC3 database.
* Much of how this library has been structured was modeled off of the amazing work done on the [pyAirtable module](https://github.com/gtalarico/pyairtable).

## License
`MIT License <https://opensource.org/licenses/MIT>`_